@@ -18,7 +18,11 @@ from io import open
 
 class UnshortenIt(object):
 
-    _headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 5.1) AppleWebKit/535.2 (KHTML, like Gecko) Chrome/15.0.874.121 Safari/535.2'}
+    _headers = {'Accept': 'text/html,application/xhtml+xml,application/xml;q=0.9,image/webp,*/*;q=0.8',
+                'Accept-Encoding': 'gzip,deflate,sdch',
+                'Accept-Language': 'en-US,en;q=0.8',
+                'Connection': 'keep-alive',
+                'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/30.0.1599.69 Safari/537.36'}
     _adfly_regex = r'adf\.ly|q\.gs|j\.gs|u\.bb'
     _linkbucks_regex = r'linkbucks\.com|any\.gs|cash4links\.co|cash4files\.co|dyo\.gs|filesonthe\.net|goneviral\.com|megaline\.co|miniurls\.co|qqc\.co|seriousdeals\.net|theseblogs\.com|theseforums\.com|tinylinks\.co|tubeviral\.com|ultrafiles\.net|urlbeat\.net|whackyvidz\.com|yyv\.co'
     _adfocus_regex = r'adfoc\.us'
@@ -52,7 +56,11 @@ class UnshortenIt(object):
             return self._unshorten_lnxlu(uri)
 
         try:
-            r = requests.get(uri, headers=self._headers)
+            # headers stop t.co from working so omit headers if this is a t.co link
+            if domain == 't.co':
+                r = requests.get(uri)
+            else:
+                r = requests.get(uri, headers=self._headers)
             return r.url, r.status_code
         except Exception as e:
             return uri, str(e)
